package com.ruoyi.agentcenter.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.ruoyi.agentcenter.domain.TAgentContraction;
import com.ruoyi.agentcenter.dto.AbnormalTask;
import com.ruoyi.agentcenter.mapper.TAgentContractionMapper;
import com.ruoyi.agentcenter.service.IAbnormalTaskService;
import com.ruoyi.agentcenter.vo.AbnormalTaskSummary;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.DeptUtils;
import com.ruoyi.system.mapper.SysDeptMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class AbnormalTaskServiceImpl implements IAbnormalTaskService
{
    @Autowired
    private TAgentContractionMapper tAgentContractionMapper;
    @Autowired
    private SysDeptMapper           sysDeptMapper;

    @Override
    public List<AbnormalTask> getAbnormalTaskList(AbnormalTask query)
    {
        switch(query.getType())
        {
            case AbnormalTask.TYPE_CONTRACTION:
                return getAbnormalContractionTaskList(query);
            default:
                return new ArrayList<>();
        }
    }

    private List<AbnormalTask> getAbnormalContractionTaskList(AbnormalTask query)
    {
        List<AbnormalTask> abnormalContractionList = tAgentContractionMapper.getAbnormalContractionList(query);
        if(CollectionUtil.isNotEmpty(abnormalContractionList))
        {
            List<SysDept> deptList = sysDeptMapper.getDeptList(new SysDept());
            Map<String, String> fullNameCache = new HashMap<>();
            abnormalContractionList.forEach((x) -> {
                String fullName = fullNameCache.computeIfAbsent(x.getOrgCode(), k -> DeptUtils.getFullNameByOrgCode(x.getOrgCode(), deptList, "/", false));
                x.setRegion(fullName);
                x.setAddress(fullName);
                x.setApplyUser("申请人XXX")
                        .setTel("联系电话1xxxxxxxxxxx")
                ;
                x.setOrderAt(DateUtils.stdRemoveTime(x.getOrderAt()));
            });
        }
        return abnormalContractionList;
    }

    @Override
    public AbnormalTaskSummary abnormalTaskSummary(AbnormalTask query)
    {
        AbnormalTaskSummary res = new AbnormalTaskSummary();
        res.setNumAbnormalContraction(getAbnormalContractionTaskCount(query));
        res.setNumAbnormalOther(0L)
                .setNumAbnormalVoucher(0L)
                ;
        res.setNum(res.getNumAbnormalContraction());
        return res;
    }

    private Long getAbnormalContractionTaskCount(AbnormalTask query)
    {
        return tAgentContractionMapper.getAbnormalContractionCount(query);
    }

    @Override
    public int removeAbnormalTask(AbnormalTask query)
    {
        switch(query.getType())
        {
            case AbnormalTask.TYPE_CONTRACTION:
                return tAgentContractionMapper.deleteTAgentContractionById(query.getId());
            default:
                return 0;
        }
    }
}
